/* eslint-disable angular/document-service,no-console,angular/log,no-alert */

(function () {
	'use strict';

	const container = document.querySelector('.parameter-container');

	var params = {};

	fetchParams();
	window.onhashchange = fetchParams;

	var hasOpener = !!window.opener;
	var liveInOctaneDialog = window.parent !== window;

	var ownerWindow;

	if (liveInOctaneDialog) {
		ownerWindow = window.parent;
	} else if (hasOpener) {
		ownerWindow = window.opener;
	}

	document.querySelector('#hasOpenerValue').innerText = hasOpener;
	document.querySelector('#hasParentValue').innerText = liveInOctaneDialog;

	if (hasOpener || liveInOctaneDialog) {
		document.querySelector('#messageOctaneButtons').style.display = 'block';
		var entityTypeInput = document.querySelector('#entity_type');
		var entityIdInput = document.querySelector('#entity_id');

		if (params.entity_type) {
			entityTypeInput.value = params.entity_type;
		}
		entityIdInput.value = params.entity_ids;

		window.refreshOctaneEntity = function refreshOctaneEntity() {
			if (!entityIdInput.value) {
				alert('No entity_id were sent');
				return;
			}

			var entityType = entityTypeInput.value;
			var entityIds = entityIdInput.value.split(',');

			var message = {
				event_name: 'octane_refresh_entity',
				workspace: params.workspace,
				shared_space: params.shared_space,
				data: {
					entity_type: entityType,
					entity_ids: entityIds,
				},
			};

			ownerWindow.postMessage(message, '*');

			console.log('octane message posted');
		};

		window.refreshOctaneList = function refreshOctaneEntity() {
			var entityType = entityTypeInput.value;

			var message = {
				event_name: 'octane_refresh_list',
				workspace: params.workspace,
				shared_space: params.shared_space,
				data: {
					entity_type: entityType,
				},
			};

			ownerWindow.postMessage(message, '*');

			console.log('octane message posted');
		};

		window.displayOctaneEntity = function displayOctaneEntity() {
			if (!entityIdInput.value) {
				alert('No entity_id was sent');
				return;
			}

			var message = {
				event_name: 'octane_display_entity',
				workspace: params.workspace,
				shared_space: params.shared_space,
				data: {
					entity_type: entityTypeInput.value,
					entity_id: entityIdInput.value,
				},
			};

			ownerWindow.postMessage(message, '*');

			console.log('octane message posted');
		};

		window.selectOctaneEntity = function displayOctaneEntity() {
			if (!entityIdInput.value) {
				alert('No entity_id were sent');
				return;
			}

			var entityIds = entityIdInput.value.split(',');

			var message = {
				event_name: 'octane_select_entity',
				workspace: params.workspace,
				shared_space: params.shared_space,
				data: {
					entity_type: entityTypeInput.value,
					entity_ids: entityIds,
				},
			};

			ownerWindow.postMessage(message, '*');

			console.log('octane message posted');
		};

		window.notifyOfNewOctaneEntity = function notifyOfNewOctaneEntity() {
			if (!entityIdInput.value) {
				alert('No entity_id was sent');
				return;
			}

			var message = {
				event_name: 'octane_entity_was_added',
				workspace: params.workspace,
				shared_space: params.shared_space,
				data: {
					entity_type: entityTypeInput.value,
					entity_id: entityIdInput.value,
				},
			};

			ownerWindow.postMessage(message, '*');

			console.log('octane message posted');
		};

		window.updateSettings = function updateSettings(context) {
			// eslint-disable-next-line no-alert
			const text = prompt('message to save to settings', '');
			if (!text) {
				return;
			}

			const message = {
				event_name: 'octane_update_settings',
				workspace: params.workspace,
				shared_space: params.shared_space,
				data: {
					context: context,
					panel_id: params.panel_id || params.dialog_id,
					settings: {text: text},
				},
			};

			ownerWindow.postMessage(message, '*');

			console.log('octane message posted');
		};

		window.readSettings = function readSettings(context) {
			const message = {
				event_name: 'octane_read_settings',
				workspace: params.workspace,
				shared_space: params.shared_space,
				data: {
					context: context,
					panel_id: params.panel_id || params.dialog_id,
				},
			};

			ownerWindow.postMessage(message, '*');

			console.log('octane message posted');
		};

		window.addEventListener('message', (event) => {
			if (event.data?.event_name === 'octane_settings') {
				const message = `Received settings: \r\n ${JSON.stringify(event.data.data, null, '  ')}`;
				console.log(message);
				alert(message);
			}
		});

		if (liveInOctaneDialog && params.dialog_id) {
			document.querySelector('#setOctaneDialogTitleBlock').style.display = 'block';
			document.querySelector('#closeOctaneDialogBlock').style.display = 'block';

			document.querySelector('#dialogId').innerText = params.dialog_id;
			window.setOctaneDialogTitle = function setOctaneDialogTitle() {
				var message = {
					event_name: 'octane_set_dialog_title',
					workspace: params.workspace,
					shared_space: params.shared_space,
					data: {
						dialog_id: params.dialog_id,
						title: document.querySelector('#dialog_title').value,
					},
				};

				ownerWindow.postMessage(message, '*');

				console.log('octane message posted');
			};

			window.setOctaneDialogTitle(); // set initial dialog title value

			window.closeOctaneDialog = function closeOctaneDialog() {
				var message = {
					event_name: 'octane_close_dialog',
					workspace: params.workspace,
					shared_space: params.shared_space,
					data: {
						dialog_id: params.dialog_id,
						refresh: document.querySelector('#refresh_results').checked,
					},
				};

				ownerWindow.postMessage(message, '*');

				console.log('octane message posted');
			};
		}
	}

	window.tryLoadOctaneData = function tryLoadOctaneData() {
		if (!params.octane_url) {
			return;
		}

		var octane_url = params.octane_url;
		var url = octane_url + '/api/shared_spaces/' + params.shared_space + '/workspaces';

		var request = new XMLHttpRequest();
		request.open('GET', url, true);
		request.withCredentials = true;
		request.setRequestHeader('Accept', 'application/json');
		request.setRequestHeader('HPECLIENTTYPE', 'external-details-app');

		request.onreadystatechange = function () {
			document.querySelector('#canFetchDataValue').innerText = request.status === 200;
		};

		request.send();
	};

	function addParam(paramsPair) {
		if (!paramsPair) {
			return;
		}

		const pair = paramsPair.split('=');
		var name = pair[0];
		var value = decodeURIComponent(pair[1]);

		params[name] = value;

		const item = document.createElement('li');
		item.innerText = name + ' : ' + value;

		container.appendChild(item);
	}

	function fetchParams() {
		params = {};
		container.innerHTML = '';

		var searchParams = document.location.search.substring(1).split('&');
		searchParams.forEach(addParam);

		var hashParams = document.location.hash.substring(1).split('&');
		hashParams.forEach(addParam);
	}
})();
